#!/bin/sh

###############################################################################
##                SETUP STAPI DEVICE NAME ENVIRONMENT VARIABLES              ##
###############################################################################

# Verify if root module is specified
# ----------------------------------
export PATH=$PATH:/sbin
#if [ -z "$MODULES_INSTALL_DIR" ] ; then
 export MODULES_INSTALL_DIR=./
#fi
. $MODULES_INSTALL_DIR/load_env.sh
# Check if we are in 32 or 29bits
# -------------------------------
if [ -f $MODULES_INSTALL_DIR/load_modules_list_29BITS.txt ]; then
 LOAD_MODULES_LIST=$MODULES_INSTALL_DIR/load_modules_list_29BITS.txt
 MODE="29BITS"
else
 MODE="32BITS"
 if [ -f $MODULES_INSTALL_DIR/load_modules_list_32BITS.txt ]; then
  LOAD_MODULES_LIST=$MODULES_INSTALL_DIR/load_modules_list_32BITS.txt
 else
  LOAD_MODULES_LIST=$MODULES_INSTALL_DIR/load_modules_list.txt
 fi
fi

###############################################################################
##                          SETUP DIRECTORY ACCESS                           ##
###############################################################################

# Verify if modules list exist
# ----------------------------
if [ ! -f $LOAD_MODULES_LIST ] ; then
 echo "$LOAD_MODULES_LIST does not exist"
 exit
fi

# Create /dev/stapi directory if not exist
# ----------------------------------------
if [ ! -e /dev/stapi ]; then mkdir -p /dev/stapi ;fi
chmod 755 /dev/stapi

###############################################################################
##                          MODULE INSERT PROCEDURE                          ##
###############################################################################

# Return chip version
# -------------------


# Load firmware (Arg 1=video1 or audio1)
# --------------------------------------


# Insert separate STAPI modules
# -----------------------------

# Insert unique STAPI module
 # Inserting sttbx_early_core which provides traces for early loaded .ko
 insmod $MODULES_INSTALL_DIR/sttbx_early_core.ko
 # We are first inserting stsys_ioctl because we need it to know the chip and cut
 echo "* Looking for chipset model and version..."
 insmod $MODULES_INSTALL_DIR/stos_core.ko
 insmod $MODULES_INSTALL_DIR/stsys_ioctl.ko
 export chipset=`cat /proc/stsys_ioctl/chipset | cut -b1-7`
 export chipver=`cat /proc/stsys_ioctl/chipset | cut -b9-9`
 rmmod stsys_ioctl
 echo "  $chipset $chipver detected"

 # Now, we load video firmware
 echo "* Loading companions"
 insmod $MODULES_INSTALL_DIR/lxload.ko type=video1
 node_name="lxload"
 major=`cat /proc/devices | grep "$node_name" | cut -b1-3`
 dev="/dev/stapi/$node_name"
   rm -f ${dev} 2> /dev/null
   mknod $dev c $major 0 || return 1
   chmod 0660 $dev || return 1

cat $MODULES_INSTALL_DIR/companion_7111_video_Ax.bin >/dev/stapi/lxload

  rmmod lxload
 insmod $MODULES_INSTALL_DIR/lxload.ko type=audio1

 node_name="lxload"
 major=`cat /proc/devices | grep "$node_name" | cut -b1-3`
 dev="/dev/stapi/$node_name"
   rm -f ${dev} 2> /dev/null
   mknod $dev c $major 0 || return 1
   chmod 0660 $dev || return 1

cat $MODULES_INSTALL_DIR/companion_7111_audio.bin >/dev/stapi/lxload

 rmmod lxload
 rmmod stos_core
 rmmod sttbx_early_core

 # Now we load multicom
 echo "* Inserting Multicom"
insmod $MODULES_INSTALL_DIR/ics.ko regions="bigphysarea,0x40000000:0x10000000"
echo "insmod ics_user.ko"
insmod $MODULES_INSTALL_DIR/ics_user.ko
echo "insmod embx.ko"
insmod $MODULES_INSTALL_DIR/embx.ko
echo "insmod embxmailbox.ko"
insmod $MODULES_INSTALL_DIR/embxmailbox.ko
echo "insmod mme.ko"
insmod $MODULES_INSTALL_DIR/mme.ko pool_size=524288
echo "insmod mme_user.ko"
insmod $MODULES_INSTALL_DIR/mme_user.ko

 # Now we load STAPI and create nodes
 echo "* Inserting STAPI Module"
 insmod $MODULES_INSTALL_DIR/stapi_all_stripped.ko
#insmod $MODULES_INSTALL_DIR/stapi_ioctl_stripped.ko
if [ ! -e /dev/input/uinput ]
then
  mknod /dev/input/uinput c 10 223
fi
echo "* Inserting uinput Module"
insmod $MODULES_INSTALL_DIR/uinput.ko
for fuItem in 0 1 2 3 4 5 6 7
do
  if [ ! -e /dev/fusion$fuItem ]
  then
    mknod /dev/fusion$fuItem c 260 $fuItem
  fi
done
##insmod fusion.ko
 echo "* Creating device nodes in /dev/stapi"
 for node_name in stfrontend_ioctl stpti4_ioctl stkeyscn_ioctl stnet_ioctl stsys_ioctl sthdmi_ioctl stsmart_ioctl \
    stblast_ioctl stsubt_ioctl stblit_ioctl stvbi_ioctl stttx_ioctl stcc_ioctl staudlx_ioctl \
    stgxobj_ioctl stvmix_ioctl stvin_ioctl stvid_ioctl stvtg_ioctl stvout_ioctl stlayer_ioctl stdenc_ioctl \
    stpwm_ioctl stpio_ioctl stspi_ioctl sti2c_ioctl stinject_ioctl stbuffer_ioctl stavmem_ioctl stmerge_ioctl \
    stfdma_ioctl stclkrv_ioctl stcommon_ioctl stevt_ioctl stuart_ioctl stpower_ioctl  ;do
	major=`cat /proc/devices | grep "$node_name" | cut -b1-3`
	dev="/dev/stapi/$node_name"
	rm -f ${dev} 2> /dev/null
	echo "make node for" $dev $major
	mknod $dev c $major 0
	chmod 0660 $dev
done
####YWDRIVER_MODI lwj add begin#######
rm -rf /dev/dvb
mkdir /dev/dvb
mkdir /dev/dvb/adapter0
chmod -R 755 /dev/dvb

#major=$(cat /proc/devices | grep "$device" | cut -b1-3)
major=190
echo "device number is $major"
mknod /dev/dvb/adapter0/demux0 c $major 4
mknod /dev/dvb/adapter0/demux1 c $major 20
mknod /dev/dvb/adapter0/demux2 c $major 36
mknod /dev/dvb/adapter0/demux3 c $major 52

mknod /dev/dvb/adapter0/ca0 c $major 6
mknod /dev/dvb/adapter0/ca1 c $major 22
mknod /dev/dvb/adapter0/ca2 c $major 38
mknod /dev/dvb/adapter0/ca3 c $major 54

mknod /dev/dvb/adapter0/swap0 c $major 15
mknod /dev/sci0 c 169 0
mknod /dev/sci1 c 169 1

insmod $MODULES_INSTALL_DIR/flash_rwmode_set.ko
rm -f /dev/mtd_rwmode_set
MTD_RWMODE_SET_MAJOR=`cat /proc/devices |grep mtd_rwmode_set|awk '{print $1}'`
mknod /dev/mtd_rwmode_set c $MTD_RWMODE_SET_MAJOR 0

insmod $MODULES_INSTALL_DIR/rt73.ko
insmod $MODULES_INSTALL_DIR/rt5370sta.ko
insmod $MODULES_INSTALL_DIR/rt3070sta.ko
insmod $MODULES_INSTALL_DIR/zd1211b.ko
insmod $MODULES_INSTALL_DIR/zd1211.ko
insmod $MODULES_INSTALL_DIR/8712u.ko
insmod $MODULES_INSTALL_DIR/8192cu.ko
####YWDRIVER_MODI lwj add end#########
insmod $MODULES_INSTALL_DIR/usb_wwan.ko
insmod $MODULES_INSTALL_DIR/option.ko
insmod $MODULES_INSTALL_DIR/pl2303.ko
####YWDRIVER_MODI lf add begin########
insmod $MODULES_INSTALL_DIR/sierra.ko
####YWDRIVER_MODI lf add end##########
####YWDRIVER_MODI lf add begin########
insmod $MODULES_INSTALL_DIR/encrypt.ko
major=`cat /proc/devices |grep sparkid|awk '{print $1}'`
rm -f /dev/sparkid
mknod /dev/sparkid c $major 0
####YWDRIVER_MODI lf add end##########

